@@ -10,6 +10,7 @@ Copyright (c) 2009 Ollix. All rights reserved.
 import os
 import sys
 import optparse
+import ConfigParser
 
 import pkg_resources
 
@@ -62,7 +63,9 @@ class Command(object):
         usage: The usage message displayed in help message.
         description: description displayed in the help message.
         version: The string to print when supplying --version option.
+        config: The ConfigParser object read specified config file.
         config_filename: A string of used config filename.
+        config_section: The section name used to set command options.
         required_options: A list of required command options.
         subcommand_entry_point: The entry point of subcommands.
     """
@@ -70,7 +73,9 @@ class Command(object):
     usage = '%prog [options] arg1 arg2 ...'
     description = None
     version = None
+    config = None
     config_filename = None
+    config_section = 'options'
     required_options = None
     subcommand_entry_point = None
 
@@ -106,27 +111,22 @@ class Command(object):
            not os.path.isfile(self.config_filename):
             return
 
-        config_file = open(self.config_filename, 'r')
+        config = ConfigParser.ConfigParser()
+        config.read(self.config_filename)
+
+        # Returns if not found the option section
+        if not config.has_section(self.config_section):
+            return
+
         arg_index = 0
-        for line in config_file:
-            # Ignore from `#` to the end of line
-            line = line.split('#', 1)[0].strip()
-            if not line:
-                continue
-            # Add parameters to `self.config` variable
-            try:
-                key, value = line.split('=')
-            except ValueError:
-                if ' ' not in line:
-                    option = '--%s' % line
-                else:
-                    error_msg = "Syntax error in config file: %r" % line
-                    raise oparse.CommandError(error_msg)
+        for option_name, option_value in config.items(self.config_section):
+            if option_value:
+                option = '--%s=%s' % (option_name, option_value)
             else:
-                option = '--%s=%s' % (key.strip(), value.strip())
+                option = '--%s' % option_name
             args.insert(arg_index, option)
             arg_index += 1
-        config_file.close()
+        self.config = config
 
     def __check_required_options(self, options):
         """Check required options.
@@ -198,6 +198,8 @@ class Command(object):
             command_instance = command_class()
         else:
             command_instance = self
+        # Set config instance
+        command_instance.config = self.config
         # Check required parameters
         command_instance.__check_required_options(options)
         # Execute the command
